XlibClient

Struct XlibClient 

pub struct XlibClient<X: XlibRef> { /* private fields */ }

Implementations

Source

impl<X: XlibRef> XlibClient<X>

pub unsafe fn init( x: X, display: *mut Display, im_name: Option<&str>, ) -> Result<Self, ClientError>

Initialize a new XlibClient from an Xlib connection.

Safety

The display pointer must be a valid Xlib display.

pub unsafe fn filter_event( &mut self, e: &XEvent, handler: &mut impl ClientHandler<Self>, ) -> Result<bool, ClientError>

Filter an event and call the handler if it is relevant.

Safety

The event e must be a valid Xlib event.