pub struct XlibClient<X: XlibRef> { /* private fields */ }Implementations
Sourceimpl<X: XlibRef> XlibClient<X>
impl<X: XlibRef> XlibClient<X>
Sourcepub unsafe fn init(
x: X,
display: *mut Display,
im_name: Option<&str>,
) -> Result<Self, ClientError>
pub unsafe fn init( x: X, display: *mut Display, im_name: Option<&str>, ) -> Result<Self, ClientError>
Initialize a new XlibClient from an Xlib connection.
Safety
The display pointer must be a valid Xlib display.
Sourcepub unsafe fn filter_event(
&mut self,
e: &XEvent,
handler: &mut impl ClientHandler<Self>,
) -> Result<bool, ClientError>
pub unsafe fn filter_event( &mut self, e: &XEvent, handler: &mut impl ClientHandler<Self>, ) -> Result<bool, ClientError>
Filter an event and call the handler if it is relevant.
Safety
The event e must be a valid Xlib event.